Changelog
=========

1.1 (2018-11-26)
----------------

- Add a subtemplate with migration utils.
  [erral]


1.0.0 (2018-10-19)
------------------

- Link to starzel buildout for hotfix installation
  [erral]

- Improve docs
  [erral]

- More tests
  [erral]

1.0b1 (2018-10-18)
------------------

- No changes yet.
